@@ -42,7 +42,7 @@ def suppress_autotime(model, fields):
 def _migrate_tasks(project_path, project):
     """ Migrate tasks from json file to database objects"""
     tasks_path = project_path / 'tasks.json'
-    with io.open(os.path.abspath(tasks_path)) as t:
+    with io.open(os.path.abspath(tasks_path), encoding='utf-8') as t:
         tasks_data = json.load(t)
         for task_id, task_data in tasks_data.items():
             task = Task.objects.create(data=task_data.get('data', {}), project=project)
@@ -50,7 +50,7 @@ def _migrate_tasks(project_path, project):
             # migrate annotations
             annotations_path = project_path / 'completions' / '{}.json'.format(task_id)
             if annotations_path.exists():
-                with io.open(os.path.abspath(annotations_path)) as c:
+                with io.open(os.path.abspath(annotations_path), encoding='utf-8') as c:
                     annotations_data = json.load(c)
                     for annotation in annotations_data['completions']:
                         task_annotation = Annotation(
@@ -81,7 +81,7 @@ def _migrate_tabs(project_path, project):
     """Migrate tabs from tabs.json to Views table"""
     tabs_path = project_path / 'tabs.json'
     if tabs_path.exists():
-        with io.open(os.path.abspath(tabs_path)) as t:
+        with io.open(os.path.abspath(tabs_path), encoding='utf-8') as t:
             tabs_data = json.load(t)
             for tab in tabs_data['tabs']:
                 view = View.objects.create(project=project)
