@@ -11,18 +11,25 @@ https://docs.djangoproject.com/en/3.1/ref/settings/
 """
 import os
 import re
+import logging
+
+# for printing messages before main logging config applied
+if not logging.getLogger().hasHandlers():
+    logging.basicConfig(level=logging.DEBUG, format='%(message)s')
 
 from label_studio.core.utils.io import get_data_dir
 from label_studio.core.utils.params import get_bool_env, get_env
 
+logger = logging.getLogger(__name__)
+
 # Hostname is used for proper path generation to the resources, pages, etc
 HOSTNAME = get_env('HOST', '')
 if HOSTNAME:
     if not HOSTNAME.startswith('http://') and not HOSTNAME.startswith('https://'):
-        print("! HOST variable found in environment, but it must start with http:// or https://, ignore it:", HOSTNAME)
+        logger.info("! HOST variable found in environment, but it must start with http:// or https://, ignore it: %s", HOSTNAME)
         HOSTNAME = ''
     else:
-        print("=> Hostname correctly is set to:", HOSTNAME)
+        logger.info("=> Hostname correctly is set to: %s", HOSTNAME)
         if HOSTNAME.endswith('/'):
             HOSTNAME = HOSTNAME[0:-1]
 
@@ -33,7 +40,7 @@ if HOSTNAME:
             match = pattern.match(HOSTNAME)
             FORCE_SCRIPT_NAME = match.group(3)
             if FORCE_SCRIPT_NAME:
-                print("=> Django URL prefix is set to:", FORCE_SCRIPT_NAME)
+                logger.info("=> Django URL prefix is set to: %s", FORCE_SCRIPT_NAME)
 
 INTERNAL_PORT = '8080'
 
@@ -42,6 +49,8 @@ SECRET_KEY = '$(fefwefwef13;LFK{P!)@#*!)kdsjfWF2l+i5e3t(8a1n'
 
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = get_bool_env('DEBUG', True)
+DEBUG_MODAL_EXCEPTIONS = get_bool_env('DEBUG_MODAL_EXCEPTIONS', True)
+
 
 # Build paths inside the project like this: os.path.join(BASE_DIR, ...)
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
@@ -49,10 +58,11 @@ BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 # Base path for media root and other uploaded files
 BASE_DATA_DIR = get_env('BASE_DATA_DIR', get_data_dir())
 os.makedirs(BASE_DATA_DIR, exist_ok=True)
-print('=> Database and media directory:', BASE_DATA_DIR)
+logger.info('=> Database and media directory: %s', BASE_DATA_DIR)
 
 # Databases
 # https://docs.djangoproject.com/en/2.1/ref/settings/#databases
+DJANGO_DB_MYSQL = 'mysql'
 DJANGO_DB_SQLITE = 'sqlite'
 DJANGO_DB = 'default'
 DATABASE_NAME_DEFAULT = os.path.join(BASE_DATA_DIR, 'label_studio.sqlite3')
@@ -66,6 +76,14 @@ DATABASES_ALL = {
         'HOST': get_env('POSTGRE_HOST', 'localhost'),
         'PORT': int(get_env('POSTGRE_PORT', '5432')),
     },
+    DJANGO_DB_MYSQL: {
+        'ENGINE': 'django.db.backends.mysql',
+        'USER': get_env('MYSQL_USER', 'root'),
+        'PASSWORD': get_env('MYSQL_PASSWORD', ''),
+        'NAME': get_env('MYSQL_NAME', 'labelstudio'),
+        'HOST': get_env('MYSQL_HOST', 'localhost'),
+        'PORT': int(get_env('MYSQL_PORT', '3306')),
+    },
     DJANGO_DB_SQLITE: {
         'ENGINE': 'django.db.backends.sqlite3',
         'NAME': DATABASE_NAME,
@@ -93,16 +111,16 @@ LOGGING = {
     },
     'handlers': {
         'console_raw': {
-            'level': get_env('LOG_LEVEL', 'DEBUG'),
+            'level': get_env('LOG_LEVEL', 'WARNING'),
             'class': 'logging.StreamHandler',
         },
         'console': {
-            'level': get_env('LOG_LEVEL', 'DEBUG'),
+            'level': get_env('LOG_LEVEL', 'WARNING'),
             'class': 'logging.StreamHandler',
             'formatter': 'standard'
         },
         'rq_console': {
-            'level': 'DEBUG',
+            'level': 'WARNING',
             'class': 'rq.utils.ColorizingStreamHandler',
             'formatter': 'rq_console',
             'exclude': ['%(asctime)s'],
@@ -110,10 +128,28 @@ LOGGING = {
     },
     'root': {
         'handlers': ['console'],
-        'level': get_env('LOG_LEVEL', 'DEBUG'),
+        'level': get_env('LOG_LEVEL', 'WARNING'),
     }
 }
 
+if get_bool_env('GOOGLE_LOGGING_ENABLED', False):
+    logging.info('Google Cloud Logging handler is enabled.')
+    try:
+        import google.cloud.logging
+        from google.auth.exceptions import GoogleAuthError
+
+        client = google.cloud.logging.Client()
+        client.setup_logging()
+
+        LOGGING['handlers']['google_cloud_logging'] = {
+            'level': get_env('LOG_LEVEL', 'WARNING'),
+            'class': 'google.cloud.logging.handlers.CloudLoggingHandler',
+            'client': client
+        }
+        LOGGING['root']['handlers'].append('google_cloud_logging')
+    except GoogleAuthError as e:
+        logger.exception('Google Cloud Logging handler could not be setup.')
+
 INSTALLED_APPS = [
     'django.contrib.admin',
     'django.contrib.auth',
@@ -140,12 +176,14 @@ INSTALLED_APPS = [
     'users',
     'organizations',
     'data_import',
+    'data_export',
 
     'projects',
     'tasks',
     'data_manager',
     'io_storages',
-    'ml'
+    'ml',
+    'webhooks',
 ]
 
 MIDDLEWARE = [
@@ -290,7 +328,7 @@ USE_TZ = True
 STATIC_URL = '/static/'
 # if FORCE_SCRIPT_NAME:
 #    STATIC_URL = FORCE_SCRIPT_NAME + STATIC_URL
-print(f'=> Static URL is set to: {STATIC_URL}')
+logger.info(f'=> Static URL is set to: {STATIC_URL}')
 
 STATIC_ROOT = os.path.join(BASE_DIR, 'static_build')
 STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static')]
@@ -307,6 +345,7 @@ CSRF_COOKIE_HTTPONLY = bool(int(get_env('CSRF_COOKIE_HTTPONLY', SESSION_COOKIE_S
 
 # user media files
 MEDIA_ROOT = os.path.join(BASE_DATA_DIR, 'media')
+os.makedirs(MEDIA_ROOT, exist_ok=True)
 MEDIA_URL = '/data/'
 UPLOAD_DIR = 'upload'
 AVATAR_PATH = 'avatars'
@@ -314,7 +353,11 @@ AVATAR_PATH = 'avatars'
 # project exports
 EXPORT_DIR = os.path.join(BASE_DATA_DIR, 'export')
 EXPORT_URL_ROOT = '/export/'
+# old export dir
 os.makedirs(EXPORT_DIR, exist_ok=True)
+# dir for delayed export
+DELAYED_EXPORT_DIR = 'export'
+os.makedirs(os.path.join(BASE_DATA_DIR, MEDIA_ROOT, DELAYED_EXPORT_DIR), exist_ok=True)
 
 # file / task size limits
 DATA_UPLOAD_MAX_MEMORY_SIZE = int(get_env('DATA_UPLOAD_MAX_MEMORY_SIZE', 250 * 1024 * 1024))
@@ -354,13 +397,17 @@ VERSION_EDITION = 'Community Edition'
 LATEST_VERSION_CHECK = True
 VERSIONS_CHECK_TIME = 0
 ALLOW_ORGANIZATION_WEBHOOKS = get_bool_env('ALLOW_ORGANIZATION_WEBHOOKS', False)
+CONVERTER_DOWNLOAD_RESOURCES = get_bool_env('CONVERTER_DOWNLOAD_RESOURCES', True)
+EXPERIMENTAL_FEATURES = get_bool_env('EXPERIMENTAL_FEATURES', False)
 
 CREATE_ORGANIZATION = 'organizations.functions.create_organization'
 GET_OBJECT_WITH_CHECK_AND_LOG = 'core.utils.get_object.get_object_with_check_and_log'
 SAVE_USER = 'users.functions.save_user'
 USER_SERIALIZER = 'users.serializers.BaseUserSerializer'
+DATA_MANAGER_GET_ALL_COLUMNS = 'data_manager.functions.get_all_columns'
 DATA_MANAGER_ANNOTATIONS_MAP = {}
 DATA_MANAGER_ACTIONS = {}
+DATA_MANAGER_CUSTOM_FILTER_EXPRESSIONS = ''
 USER_LOGIN_FORM = 'users.forms.LoginForm'
 PROJECT_MIXIN = 'core.mixins.DummyModelMixin'
 TASK_MIXIN = 'core.mixins.DummyModelMixin'
@@ -369,6 +416,8 @@ ORGANIZATION_MIXIN = 'core.mixins.DummyModelMixin'
 USER_MIXIN = 'users.mixins.UserMixin'
 GET_STORAGE_LIST = 'io_storages.functions.get_storage_list'
 
+STORAGE_ANNOTATION_SERIALIZER = 'io_storages.serializers.StorageAnnotationSerializer'
+
 
 def project_delete(project):
     project.delete()
@@ -386,9 +435,9 @@ PROJECT_DELETE = project_delete
 USER_AUTH = user_auth
 COLLECT_VERSIONS = collect_versions_dummy
 
+WEBHOOK_TIMEOUT = float(get_env('WEBHOOK_TIMEOUT', 1.0))
+
 # fix a problem with Windows mimetypes for JS and PNG
 import mimetypes
 mimetypes.add_type("application/javascript", ".js", True)
 mimetypes.add_type("image/png", ".png", True)
-
-print()  # just empty line
