@@ -2,6 +2,7 @@
 """
 from rest_framework.exceptions import APIException, ValidationError
 from rest_framework import status
+from lxml.etree import XMLSyntaxError
 
 
 class LabelStudioError(Exception):
@@ -37,3 +38,7 @@ class LabelStudioAPIExceptionSentryIgnored(LabelStudioAPIException):
 
 class LabelStudioValidationErrorSentryIgnored(ValidationError):
     pass
+
+
+class LabelStudioXMLSyntaxErrorSentryIgnored(Exception):
+    pass
