@@ -18,13 +18,14 @@ def bool_from_request(params, key, default):
 
 
 def cast_bool_from_str(value):
-    if value.lower() in ['true', 'yes', 'on', '1']:
-        value = True
-    elif value.lower() in ['false', 'no', 'not', 'off', '0']:
-        value = False
-    else:
-        raise ValueError(f'Incorrect bool value "{value}". '
-                         f'It should be one of [1, 0, true, false, yes, no]')
+    if isinstance(value, str):
+        if value.lower() in ['true', 'yes', 'on', '1']:
+            value = True
+        elif value.lower() in ['false', 'no', 'not', 'off', '0']:
+            value = False
+        else:
+            raise ValueError(f'Incorrect bool value "{value}". '
+                             f'It should be one of [1, 0, true, false, yes, no]')
     return value
 
 
@@ -89,3 +90,15 @@ def get_env(name, default=None, is_bool=False):
 
 def get_bool_env(key, default):
     return get_env(key, default, is_bool=True)
+
+
+def get_env_list_int(key, default=None):
+    """
+    "1,2,3" in env variable => [1, 2, 3] in python
+    """
+    value = get_env(key)
+    if not value:
+        if default is None:
+            return []
+        return default
+    return [int(el) for el in value.split(',')]
