@@ -1,9 +1,11 @@
 """This file and its contents are licensed under the Apache License 2.0. Please see the included NOTICE for copyright information and LICENSE for a copy of the license.
 """
+import os
 import time
 import logging
 import drf_yasg.openapi as openapi
 import json
+import mimetypes
 
 from django.conf import settings
 from django.db import transaction
@@ -23,6 +25,9 @@ from .uploader import load_tasks
 from .serializers import ImportApiSerializer, FileUploadSerializer
 from .models import FileUpload
 
+from webhooks.utils import emit_webhooks_for_instance
+from webhooks.models import WebhookAction
+
 logger = logging.getLogger(__name__)
 
 
@@ -165,7 +170,10 @@ class ImportAPI(generics.CreateAPIView):
     def _save(self, tasks):
         serializer = self.get_serializer(data=tasks, many=True)
         serializer.is_valid(raise_exception=True)
-        return serializer.save(project_id=self.kwargs['pk']), serializer
+        task_instances = serializer.save(project_id=self.kwargs['pk'])
+        project = generics.get_object_or_404(Project.objects.for_user(self.request.user), pk=self.kwargs['pk'])
+        emit_webhooks_for_instance(self.request.user.active_organization, project, WebhookAction.TASKS_CREATED, task_instances)
+        return task_instances, serializer
 
     def create(self, request, *args, **kwargs):
         start = time.time()
@@ -338,6 +346,7 @@ class FileUploadListAPI(generics.mixins.ListModelMixin,
             raise ValueError('"file_upload_ids" parameter must be a list of integers')
         return Response({'deleted': deleted}, status=status.HTTP_200_OK)
 
+
 @method_decorator(name='get', decorator=swagger_auto_schema(
         tags=['Import'],
         operation_summary='Get file upload',
@@ -382,6 +391,15 @@ class UploadedFileResponse(generics.RetrieveAPIView):
         filename = kwargs['filename']
         file = settings.UPLOAD_DIR + ('/' if not settings.UPLOAD_DIR.endswith('/') else '') + filename
         logger.debug(f'Fetch uploaded file by user {request.user} => {file}')
-        file_upload = FileUpload.objects.get(file=file)
+        file_upload = FileUpload.objects.filter(file=file).last()
 
-        return RangedFileResponse(request, open(file_upload.file.path, mode='rb'))
+        if not file_upload.has_permission(request.user):
+            return Response(status=status.HTTP_403_FORBIDDEN)
+
+        file = file_upload.file
+        if file.storage.exists(file.name):
+            content_type, encoding = mimetypes.guess_type(str(file.name))
+            content_type = content_type or 'application/octet-stream'
+            return RangedFileResponse(request, file.open(mode='rb'), content_type=content_type)
+        else:
+            return Response(status=status.HTTP_404_NOT_FOUND)
