@@ -1,12 +1,19 @@
 """This file and its contents are licensed under the Apache License 2.0. Please see the included NOTICE for copyright information and LICENSE for a copy of the license.
 """
+import logging
+
 from django.db.models import signals
 
-from tasks.models import Annotation, Prediction, update_is_labeled_after_removing_annotation
+from core.permissions import AllPermissions
 from core.utils.common import temporary_disconnect_signal, temporary_disconnect_all_signals
-
+from tasks.models import Annotation, Prediction, update_is_labeled_after_removing_annotation
+from webhooks.utils import emit_webhooks_for_instance
+from webhooks.models import WebhookAction
 from data_manager.functions import evaluate_predictions
 
+all_permissions = AllPermissions()
+logger = logging.getLogger(__name__)
+
 
 def retrieve_tasks_predictions(project, queryset, **kwargs):
     """ Retrieve predictions by tasks ids
@@ -24,7 +31,8 @@ def delete_tasks(project, queryset, **kwargs):
     :param project: project instance
     :param queryset: filtered tasks db queryset
     """
-    count = queryset.count()
+    tasks_ids = list(queryset.values('id'))
+    count = len(tasks_ids)
 
     # delete all project tasks
     if count == project.tasks.count():
@@ -44,6 +52,8 @@ def delete_tasks(project, queryset, **kwargs):
         with temporary_disconnect_signal(signals.post_delete, update_is_labeled_after_removing_annotation, Annotation):
             queryset.delete()
 
+    emit_webhooks_for_instance(project.organization, project, WebhookAction.TASKS_DELETED, tasks_ids)
+
     # remove all tabs if there are no tasks in project
     reload = False
     if not project.tasks.exists():
@@ -63,7 +73,9 @@ def delete_tasks_annotations(project, queryset, **kwargs):
     task_ids = queryset.values_list('id', flat=True)
     annotations = Annotation.objects.filter(task__id__in=task_ids)
     count = annotations.count()
+    annotations_ids = list(annotations.values('id'))
     annotations.delete()
+    emit_webhooks_for_instance(project.organization, project, WebhookAction.ANNOTATIONS_DELETED, annotations_ids)
     return {'processed_items': count,
             'detail': 'Deleted ' + str(count) + ' annotations'}
 
@@ -84,12 +96,12 @@ def delete_tasks_predictions(project, queryset, **kwargs):
 actions = [
     {
         'entry_point': retrieve_tasks_predictions,
-        'title': 'Retrieve predictions',
+        'permission': all_permissions.predictions_any,
+        'title': 'Retrieve Predictions',
         'order': 90,
-        'permissions': 'can_manage_annotations',
         'dialog': {
             'text': 'Send the selected tasks to all ML backends connected to the project.'
-                    'This operation migth be abruptly interrupted due to a timeout. ' 
+                    'This operation might be abruptly interrupted due to a timeout. '
                     'The recommended way to get predictions is to update tasks using the Label Studio API.'
                     '<a href="https://labelstud.io/guide/ml.html>See more in the documentation</a>.'
                     'Please confirm your action.',
@@ -98,8 +110,9 @@ actions = [
     },
     {
         'entry_point': delete_tasks,
-        'title': 'Delete tasks', 'order': 100,
-        'permissions': 'can_delete_tasks',
+        'permission': all_permissions.tasks_delete,
+        'title': 'Delete Tasks',
+        'order': 100,
         'reload': True,
         'dialog': {
             'text': 'You are going to delete the selected tasks. Please confirm your action.',
@@ -108,9 +121,9 @@ actions = [
     },
     {
         'entry_point': delete_tasks_annotations,
-        'title': 'Delete annotations',
+        'permission': all_permissions.tasks_delete,
+        'title': 'Delete Annotations',
         'order': 101,
-        'permissions': 'can_manage_annotations',
         'dialog': {
             'text': 'You are going to delete all annotations from the selected tasks. Please confirm your action.',
             'type': 'confirm'
@@ -118,9 +131,9 @@ actions = [
     },
     {
         'entry_point': delete_tasks_predictions,
-        'title': 'Delete predictions',
+        'permission': all_permissions.predictions_any,
+        'title': 'Delete Predictions',
         'order': 102,
-        'permissions': 'can_manage_annotations',
         'dialog': {
             'text': 'You are going to delete all predictions from the selected tasks. Please confirm your action.',
             'type': 'confirm'
