@@ -5,8 +5,11 @@ import logging
 from copy import copy, deepcopy
 from data_manager.functions import DataManagerException
 from core.utils.common import timestamp_now
+from core.permissions import AllPermissions
+
 
 logger = logging.getLogger(__name__)
+all_permissions = AllPermissions()
 
 
 def propagate_annotations(project, queryset, **kwargs):
@@ -46,40 +49,11 @@ def propagate_annotations(project, queryset, **kwargs):
     return {'response_code': 200}
 
 
-def predictions_to_annotations(project, items, **kwargs):
-    for i in items:
-        task = project.source_storage.get(i)
-        predictions = task.get('predictions', [])
-        if len(predictions) == 0:
-            continue
-
-        prediction = predictions[-1]
-
-        # load task with annotation from target storage
-        task_with_annotations = project.target_storage.get(i)
-        task = copy(task if task_with_annotations is None else task_with_annotations)
-
-        annotations = task.get('annotations', None) or [{'id': i * 9000}]
-        annotation = {
-            'id': max([c['id'] for c in annotations]) + 1,
-            'created_at': timestamp_now(),
-            'lead_time': 0,
-            'result': prediction.get('result', [])
-        }
-
-        if 'annotations' not in task:
-            task['annotations'] = []
-        task['annotations'].append(annotation)
-
-        project.target_storage.set(i, task)
-
-    return {'response_code': 200}
-
-
 actions = [
     {
         'entry_point': propagate_annotations,
-        'title': 'Propagate annotations',
+        'permission': all_permissions.tasks_change,
+        'title': 'Propagate Annotations',
         'order': 1,
         'experimental': True,
         'dialog': {
@@ -97,16 +71,5 @@ actions = [
                     'will have a lot of issues.',
             'type': 'confirm'
         }
-    },
-
-    {
-        'entry_point': predictions_to_annotations,
-        'title': 'Predictions => annotations',
-        'order': 1,
-        'experimental': True,
-        'dialog': {
-            'text': 'This action will create a new annotation from the last task prediction for each selected task.',
-            'type': 'confirm'
-        }
     }
 ]
