@@ -16,14 +16,14 @@ class RedisImportStorageSerializer(ImportStorageSerializer):
 
     def validate(self, data):
         data = super(RedisImportStorageSerializer, self).validate(data)
+
         storage = RedisImportStorage(**data)
         try:
             storage.validate_connection()
-        except Exception as exc:
-            raise ValidationError(exc)
+        except:
+            raise ValidationError("Can't connect to Redis server.")
         return data
 
-
 class RedisExportStorageSerializer(ExportStorageSerializer):
     type = serializers.ReadOnlyField(default=os.path.basename(os.path.dirname(__file__)))
 
