@@ -12,9 +12,8 @@ from rest_framework.response import Response
 from drf_yasg.utils import swagger_auto_schema
 from django.utils.decorators import method_decorator
 
-from label_studio.core.mixins import APIViewVirtualRedirectMixin, APIViewVirtualMethodMixin
 from label_studio.core.permissions import all_permissions, ViewClassPermission
-from label_studio.core.utils.common import get_object_with_check_and_log
+from label_studio.core.utils.common import get_object_with_check_and_log, bool_from_request
 
 from organizations.models import Organization
 from organizations.serializers import (
@@ -76,13 +75,15 @@ class OrganizationMemberListAPI(generics.ListAPIView):
     )
     serializer_class = OrganizationMemberUserSerializer
 
+    def get_serializer_context(self):
+        return {
+            'contributed_to_projects': bool_from_request(self.request.GET, 'contributed_to_projects', False)
+        }
+
     def get_queryset(self):
         org = generics.get_object_or_404(self.request.user.organizations, pk=self.kwargs[self.lookup_field])
         return org.members.order_by('user__username')
 
-    def get(self, request, *args, **kwargs):
-        return super(OrganizationMemberListAPI, self).get(request, *args, **kwargs)
-
 
 @method_decorator(name='get', decorator=swagger_auto_schema(
         tags=['Organizations'],
@@ -94,9 +95,7 @@ class OrganizationMemberListAPI(generics.ListAPIView):
         operation_summary='Update organization settings',
         operation_description='Update the settings for a specific organization by ID.'
     ))
-class OrganizationAPI(APIViewVirtualRedirectMixin,
-                      APIViewVirtualMethodMixin,
-                      generics.RetrieveUpdateAPIView):
+class OrganizationAPI(generics.RetrieveUpdateAPIView):
 
     parser_classes = (JSONParser, FormParser, MultiPartParser)
     queryset = Organization.objects.all()
