@@ -15,8 +15,15 @@ from tasks.models import Task, Prediction, Annotation, Q_task_finished_annotatio
 from core.utils.common import create_hash, sample_query, get_attr_or_item, load_func
 from core.utils.exceptions import LabelStudioValidationErrorSentryIgnored
 from core.label_config import (
-    parse_config, validate_label_config, extract_data_types, get_all_object_tag_names, config_line_stipped,
-    get_sample_task, get_all_labels, get_all_control_tag_tuples, get_annotation_tuple
+    parse_config,
+    validate_label_config,
+    extract_data_types,
+    get_all_object_tag_names,
+    config_line_stipped,
+    get_sample_task,
+    get_all_labels,
+    get_all_control_tag_tuples,
+    get_annotation_tuple,
 )
 
 logger = logging.getLogger(__name__)
@@ -26,34 +33,49 @@ class ProjectManager(models.Manager):
     def for_user(self, user):
         return self.filter(organization=user.active_organization)
 
+    COUNTER_FIELDS = [
+        'task_number',
+        'finished_task_number',
+        'total_predictions_number',
+        'total_annotations_number',
+        'num_tasks_with_annotations',
+        'useful_annotation_number',
+        'ground_truth_number',
+        'skipped_annotations_number',
+    ]
+
     def with_counts(self):
-        return self.annotate(
+        return self.with_counts_annotate(self)
+
+    @staticmethod
+    def with_counts_annotate(queryset):
+        return queryset.annotate(
             task_number=Count('tasks', distinct=True),
+            finished_task_number=Count('tasks', distinct=True, filter=Q(tasks__is_labeled=True)),
             total_predictions_number=Count('tasks__predictions', distinct=True),
             total_annotations_number=Count(
-                'tasks__annotations__id', distinct=True,
-                filter=Q(tasks__annotations__was_cancelled=False)
+                'tasks__annotations__id', distinct=True, filter=Q(tasks__annotations__was_cancelled=False)
             ),
             num_tasks_with_annotations=Count(
-                'tasks__id', distinct=True,
-                filter=Q(tasks__annotations__isnull=False) &
-                    Q(tasks__annotations__ground_truth=False) &
-                    Q(tasks__annotations__was_cancelled=False) &
-                    Q(tasks__annotations__result__isnull=False)
+                'tasks__id',
+                distinct=True,
+                filter=Q(tasks__annotations__isnull=False)
+                & Q(tasks__annotations__ground_truth=False)
+                & Q(tasks__annotations__was_cancelled=False)
+                & Q(tasks__annotations__result__isnull=False),
             ),
             useful_annotation_number=Count(
-                'tasks__annotations__id', distinct=True,
-                filter=Q(tasks__annotations__was_cancelled=False) &
-                    Q(tasks__annotations__ground_truth=False) &
-                    Q(tasks__annotations__result__isnull=False)
+                'tasks__annotations__id',
+                distinct=True,
+                filter=Q(tasks__annotations__was_cancelled=False)
+                & Q(tasks__annotations__ground_truth=False)
+                & Q(tasks__annotations__result__isnull=False),
             ),
             ground_truth_number=Count(
-                'tasks__annotations__id', distinct=True,
-                filter=Q(tasks__annotations__ground_truth=True)
+                'tasks__annotations__id', distinct=True, filter=Q(tasks__annotations__ground_truth=True)
             ),
             skipped_annotations_number=Count(
-                'tasks__annotations__id', distinct=True,
-                filter=Q(tasks__annotations__was_cancelled=True)
+                'tasks__annotations__id', distinct=True, filter=Q(tasks__annotations__was_cancelled=True)
             ),
         )
 
@@ -62,57 +84,101 @@ ProjectMixin = load_func(settings.PROJECT_MIXIN)
 
 
 class Project(ProjectMixin, models.Model):
-    """
-    """
+
     objects = ProjectManager()
     __original_label_config = None
-    
-    title = models.CharField(_('title'), null=True, blank=True, default='', max_length=settings.PROJECT_TITLE_MAX_LEN,
-                             help_text=f'Project name. Must be between {settings.PROJECT_TITLE_MIN_LEN} and {settings.PROJECT_TITLE_MAX_LEN} characters long.',
-                             validators=[MinLengthValidator(settings.PROJECT_TITLE_MIN_LEN), MaxLengthValidator(settings.PROJECT_TITLE_MAX_LEN)])
-    description = models.TextField(_('description'), blank=True, null=True, default='', help_text='Project description')
 
-    organization = models.ForeignKey('organizations.Organization', on_delete=models.CASCADE, related_name='projects', null=True)
-    label_config = models.TextField(_('label config'), blank=True, null=True, default='<View></View>',
-                                    help_text='Label config in XML format. See more about it in documentation')
-    expert_instruction = models.TextField(_('expert instruction'), blank=True, null=True, default='', help_text='Labeling instructions in HTML format')
-    show_instruction = models.BooleanField(_('show instruction'), default=False, help_text='Show instructions to the annotator before they start')
+    title = models.CharField(
+        _('title'),
+        null=True,
+        blank=True,
+        default='',
+        max_length=settings.PROJECT_TITLE_MAX_LEN,
+        help_text=f'Project name. Must be between {settings.PROJECT_TITLE_MIN_LEN} and {settings.PROJECT_TITLE_MAX_LEN} characters long.',
+        validators=[
+            MinLengthValidator(settings.PROJECT_TITLE_MIN_LEN),
+            MaxLengthValidator(settings.PROJECT_TITLE_MAX_LEN),
+        ],
+    )
+    description = models.TextField(
+        _('description'), blank=True, null=True, default='', help_text='Project description'
+    )
 
-    show_skip_button = models.BooleanField(_('show skip button'), default=True, help_text='Show a skip button in interface and allow annotators to skip the task')
-    enable_empty_annotation = models.BooleanField(_('enable empty annotation'), default=True, help_text='Allow annotators to submit empty annotations')
+    organization = models.ForeignKey(
+        'organizations.Organization', on_delete=models.CASCADE, related_name='projects', null=True
+    )
+    label_config = models.TextField(
+        _('label config'),
+        blank=True,
+        null=True,
+        default='<View></View>',
+        help_text='Label config in XML format. See more about it in documentation',
+    )
+    expert_instruction = models.TextField(
+        _('expert instruction'), blank=True, null=True, default='', help_text='Labeling instructions in HTML format'
+    )
+    show_instruction = models.BooleanField(
+        _('show instruction'), default=False, help_text='Show instructions to the annotator before they start'
+    )
 
-    show_annotation_history = models.BooleanField(_('show annotation history'), default=False, help_text='Show annotation history to annotator')
-    show_collab_predictions = models.BooleanField(_('show predictions to annotator'), default=True, help_text='If set, the annotator can view model predictions')
-    evaluate_predictions_automatically = models.BooleanField(_('evaluate predictions automatically'), default=False, help_text='Retrieve and display predictions when loading a task')
+    show_skip_button = models.BooleanField(
+        _('show skip button'),
+        default=True,
+        help_text='Show a skip button in interface and allow annotators to skip the task',
+    )
+    enable_empty_annotation = models.BooleanField(
+        _('enable empty annotation'), default=True, help_text='Allow annotators to submit empty annotations'
+    )
+
+    show_annotation_history = models.BooleanField(
+        _('show annotation history'), default=False, help_text='Show annotation history to annotator'
+    )
+    show_collab_predictions = models.BooleanField(
+        _('show predictions to annotator'), default=True, help_text='If set, the annotator can view model predictions'
+    )
+    evaluate_predictions_automatically = models.BooleanField(
+        _('evaluate predictions automatically'),
+        default=False,
+        help_text='Retrieve and display predictions when loading a task',
+    )
     token = models.CharField(_('token'), max_length=256, default=create_hash, null=True, blank=True)
-    result_count = models.IntegerField(_('result count'), default=0, help_text='Total results inside of annotations counter')
+    result_count = models.IntegerField(
+        _('result count'), default=0, help_text='Total results inside of annotations counter'
+    )
     color = models.CharField(_('color'), max_length=16, default='#FFFFFF', null=True, blank=True)
-    
+
     created_by = models.ForeignKey(
         settings.AUTH_USER_MODEL,
         related_name='created_projects',
         on_delete=models.SET_NULL,
         null=True,
-        verbose_name=_('created by')
+        verbose_name=_('created by'),
+    )
+    maximum_annotations = models.IntegerField(
+        _('maximum annotation number'),
+        default=1,
+        help_text='Maximum number of annotations for one task. '
+        'If the number of annotations per task is equal or greater '
+        'to this value, the task is completed (is_labeled=True)',
     )
-    maximum_annotations = models.IntegerField(_('maximum annotation number'), default=1,
-                                              help_text='Maximum number of annotations for one task. '
-                                                        'If the number of annotations per task is equal or greater '
-                                                        'to this value, the task is completed (is_labeled=True)')
     min_annotations_to_start_training = models.IntegerField(
         _('min_annotations_to_start_training'),
         default=10,
-        help_text='Minimum number of completed tasks after which model training is started'
+        help_text='Minimum number of completed tasks after which model training is started',
     )
 
     control_weights = JSONField(_('control weights'), null=True, default=dict, help_text='Weights for control tags')
-    model_version = models.TextField(_('model version'), blank=True, null=True, default='',
-                                     help_text='Machine learning model version')
+    model_version = models.TextField(
+        _('model version'), blank=True, null=True, default='', help_text='Machine learning model version'
+    )
     data_types = JSONField(_('data_types'), default=dict, null=True)
-    
+
     is_draft = models.BooleanField(
-        _('is draft'), default=False, help_text='Whether or not the project is in the middle of being created')
-    is_published = models.BooleanField(_('published'), default=False, help_text='Whether or not the project is published to annotators')
+        _('is draft'), default=False, help_text='Whether or not the project is in the middle of being created'
+    )
+    is_published = models.BooleanField(
+        _('published'), default=False, help_text='Whether or not the project is published to annotators'
+    )
     created_at = models.DateTimeField(_('created at'), auto_now_add=True)
     updated_at = models.DateTimeField(_('updated at'), auto_now=True)
 
@@ -123,18 +189,20 @@ class Project(ProjectMixin, models.Model):
     SAMPLING_CHOICES = (
         (SEQUENCE, 'Tasks are ordered by Data manager ordering'),
         (UNIFORM, 'Tasks are chosen randomly'),
-        (UNCERTAINTY, 'Tasks are chosen according to model uncertainty scores (active learning mode)')
+        (UNCERTAINTY, 'Tasks are chosen according to model uncertainty scores (active learning mode)'),
     )
 
     sampling = models.CharField(max_length=100, choices=SAMPLING_CHOICES, null=True, default=SEQUENCE)
-    show_ground_truth_first = models.BooleanField(_('show ground truth first'), default=True)
-    show_overlap_first = models.BooleanField(_('show overlap first'), default=True)
+    show_ground_truth_first = models.BooleanField(_('show ground truth first'), default=False)
+    show_overlap_first = models.BooleanField(_('show overlap first'), default=False)
     overlap_cohort_percentage = models.IntegerField(_('overlap_cohort_percentage'), default=100)
 
     task_data_login = models.CharField(
-        _('task_data_login'), max_length=256, blank=True, null=True, help_text='Task data credentials: login')
+        _('task_data_login'), max_length=256, blank=True, null=True, help_text='Task data credentials: login'
+    )
     task_data_password = models.CharField(
-        _('task_data_password'), max_length=256, blank=True, null=True, help_text='Task data credentials: password')
+        _('task_data_password'), max_length=256, blank=True, null=True, help_text='Task data credentials: password'
+    )
 
     def __init__(self, *args, **kwargs):
         super(Project, self).__init__(*args, **kwargs)
@@ -189,13 +257,16 @@ class Project(ProjectMixin, models.Model):
 
     @property
     def only_undefined_field(self):
-        return self.one_object_in_label_config and self.summary.common_data_columns \
-               and self.summary.common_data_columns[0] == settings.DATA_UNDEFINED_NAME
+        return (
+            self.one_object_in_label_config
+            and self.summary.common_data_columns
+            and self.summary.common_data_columns[0] == settings.DATA_UNDEFINED_NAME
+        )
 
     @property
     def get_labeled_count(self):
         return self.tasks.filter(is_labeled=True).count()
-    
+
     @property
     def get_collected_count(self):
         return self.tasks.count()
@@ -219,7 +290,7 @@ class Project(ProjectMixin, models.Model):
     @property
     def need_annotators(self):
         return self.maximum_annotations - self.num_annotators
-    
+
     @classmethod
     def find_by_invite_url(cls, url):
         token = url.strip('/').split('/')[-1]
@@ -251,8 +322,9 @@ class Project(ProjectMixin, models.Model):
         membership = ProjectMember.objects.filter(user=user, project=self)
         return membership.exists() and membership.first().enabled
 
-    def update_tasks_states(self, maximum_annotations_changed, overlap_cohort_percentage_changed,
-                            tasks_number_changed):
+    def update_tasks_states(
+        self, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed
+    ):
 
         # if only maximum annotations parameter is tweaked
         if maximum_annotations_changed and not overlap_cohort_percentage_changed:
@@ -273,9 +345,9 @@ class Project(ProjectMixin, models.Model):
             self._rearrange_overlap_cohort()
 
         if maximum_annotations_changed or overlap_cohort_percentage_changed:
-            bulk_update_stats_project_tasks(self.tasks.filter(
-                Q(annotations__isnull=False) &
-                Q(annotations__ground_truth=False)))
+            bulk_update_stats_project_tasks(
+                self.tasks.filter(Q(annotations__isnull=False) & Q(annotations__ground_truth=False))
+            )
 
     def _rearrange_overlap_cohort(self):
         tasks_with_overlap = self.tasks.filter(overlap__gt=1)
@@ -302,24 +374,22 @@ class Project(ProjectMixin, models.Model):
         self.tasks.filter(file_upload_id__in=file_upload_ids).delete()
 
     def advance_onboarding(self):
-        """ Move project to next onboarding step
-        """
+        """Move project to next onboarding step"""
         po_qs = self.steps_left.order_by('step__order')
         count = po_qs.count()
-        
+
         if count:
             po = po_qs.first()
             po.finished = True
             po.save()
-            
+
             return count != 1
 
     def created_at_prettify(self):
         return self.created_at.strftime("%d %b %Y %H:%M:%S")
 
     def onboarding_step_finished(self, step):
-        """ Mark specific step as finished
-        """
+        """Mark specific step as finished"""
         pos = ProjectOnboardingSteps.objects.get(code=step)
         po = ProjectOnboarding.objects.get(project=self, step=pos)
         po.finished = True
@@ -356,11 +426,15 @@ class Project(ProjectMixin, models.Model):
         fields_from_data.discard(settings.DATA_UNDEFINED_NAME)
         if fields_from_data and not fields_from_config.issubset(fields_from_data):
             different_fields = list(fields_from_config.difference(fields_from_data))
-            raise LabelStudioValidationErrorSentryIgnored(f'These fields are not present in the data: {",".join(different_fields)}')
+            raise LabelStudioValidationErrorSentryIgnored(
+                f'These fields are not present in the data: {",".join(different_fields)}'
+            )
 
         if self.num_annotations == 0:
-            logger.debug(f'Project {self} has no annotations: nothing to validate here. '
-                         f'Ensure annotations-related project summary is empty')
+            logger.debug(
+                f'Project {self} has no annotations: nothing to validate here. '
+                f'Ensure annotations-related project summary is empty'
+            )
             self.summary.reset(tasks_data_based=False)
             return
 
@@ -377,10 +451,12 @@ class Project(ProjectMixin, models.Model):
                 from_name, to_name, t = ann_tuple.split('|')
                 diff_str.append(
                     f'{self.summary.created_annotations[ann_tuple]} '
-                    f'with from_name={from_name}, to_name={to_name}, type={t}')
+                    f'with from_name={from_name}, to_name={to_name}, type={t}'
+                )
             diff_str = '\n'.join(diff_str)
             raise LabelStudioValidationErrorSentryIgnored(
-                f'Created annotations are incompatible with provided labeling schema, we found:\n{diff_str}')
+                f'Created annotations are incompatible with provided labeling schema, we found:\n{diff_str}'
+            )
 
         # validate labels consistency
         labels_from_config = get_all_labels(config_string)
@@ -390,7 +466,8 @@ class Project(ProjectMixin, models.Model):
             if labels_from_data and control_tag_from_data not in labels_from_config:
                 raise LabelStudioValidationErrorSentryIgnored(
                     f'There are {sum(labels_from_data.values(), 0)} annotation(s) created with tag '
-                    f'"{control_tag_from_data}", you can\'t remove it')
+                    f'"{control_tag_from_data}", you can\'t remove it'
+                )
             labels_from_config_by_tag = set(labels_from_config[control_tag_from_data])
             if not set(labels_from_data).issubset(set(labels_from_config_by_tag)):
                 different_labels = list(set(labels_from_data).difference(labels_from_config_by_tag))
@@ -417,7 +494,7 @@ class Project(ProjectMixin, models.Model):
             control_weights[control_name] = {
                 'overall': 1.0,
                 'type': control_type,
-                'labels': {label: 1.0 for label in outputs[control_name].get('labels', [])}
+                'labels': {label: 1.0 for label in outputs[control_name].get('labels', [])},
             }
         return control_weights
 
@@ -444,7 +521,7 @@ class Project(ProjectMixin, models.Model):
             self.update_tasks_states(
                 maximum_annotations_changed=self.__maximum_annotations != self.maximum_annotations,
                 overlap_cohort_percentage_changed=self.__overlap_cohort_percentage != self.overlap_cohort_percentage,
-                tasks_number_changed=False
+                tasks_number_changed=False,
             )
             self.__maximum_annotations = self.maximum_annotations
             self.__overlap_cohort_percentage = self.overlap_cohort_percentage
@@ -463,6 +540,7 @@ class Project(ProjectMixin, models.Model):
             return self.team_link.team.members.values_list('user', flat=True)
         else:
             from users.models import User
+
             # TODO: may want to return all users from organization
             return User.objects.none()
 
@@ -470,9 +548,9 @@ class Project(ProjectMixin, models.Model):
         return hasattr(self, 'team_link') and self.team_link.team.has_user(user)
 
     def annotators(self):
-        """ Annotators connected to this project including team members
-        """
+        """Annotators connected to this project including team members"""
         from users.models import User
+
         member_ids = self.get_member_ids()
         team_members = User.objects.filter(id__in=member_ids).order_by('email')
 
@@ -493,7 +571,7 @@ class Project(ProjectMixin, models.Model):
         return annotators
 
     def annotators_with_annotations(self, min_count=500):
-        """ Annotators with annotation number > min_number
+        """Annotators with annotation number > min_number
 
         :param min_count: minimal annotation number to leave an annotators
         :return: filtered annotators
@@ -502,12 +580,13 @@ class Project(ProjectMixin, models.Model):
         q = Q(annotations__task__project=self) & Q_task_finished_annotations & Q(annotations__ground_truth=False)
         annotators = annotators.annotate(annotation_count=Count('annotations', filter=q, distinct=True))
         return annotators.filter(annotation_count__gte=min_count)
-        
+
     def labeled_tasks(self):
         return self.tasks.filter(is_labeled=True)
 
     def has_annotations(self):
         from tasks.models import Annotation  # prevent cycling imports
+
         return Annotation.objects.filter(Q(task__project=self) & Q(ground_truth=False)).count() > 0
 
     # [TODO] this should be a template tag or something like this
@@ -537,7 +616,8 @@ class Project(ProjectMixin, models.Model):
         min_n_finished_annotations = sum([ft.overlap for ft in finished_tasks])
 
         annotations_unfinished_tasks = Annotation.objects.filter(
-            task__project=self.id, task__is_labeled=False, ground_truth=False, result__isnull=False).count()
+            task__project=self.id, task__is_labeled=False, ground_truth=False, result__isnull=False
+        ).count()
 
         # get minimum remain annotations
         total_annotations_needed = self.get_total_possible_count
@@ -545,7 +625,8 @@ class Project(ProjectMixin, models.Model):
 
         # get average time of all finished TC
         finished_annotations = Annotation.objects.filter(
-            Q(task__project=self.id) & Q(ground_truth=False), result__isnull=False).values('lead_time')
+            Q(task__project=self.id) & Q(ground_truth=False), result__isnull=False
+        ).values('lead_time')
         avg_lead_time = finished_annotations.aggregate(avg_lead_time=Avg('lead_time'))['avg_lead_time']
 
         if avg_lead_time is None:
@@ -558,7 +639,7 @@ class Project(ProjectMixin, models.Model):
     def annotations_lead_time(self):
         annotations = Annotation.objects.filter(Q(task__project=self.id) & Q(ground_truth=False))
         return annotations.aggregate(avg_lead_time=Avg('lead_time'))['avg_lead_time']
-    
+
     @staticmethod
     def django_settings():
         return settings
@@ -573,34 +654,44 @@ class Project(ProjectMixin, models.Model):
     def get_parsed_config(self):
         return parse_config(self.label_config)
 
+    def get_counters(self):
+        """Method to get extra counters data from Manager method with_counts()
+        """
+        result = {}
+        for field in ProjectManager.COUNTER_FIELDS:
+            value = getattr(self, field, None)
+            if value is not None:
+                result[field] = value
+        return result
+
     def __str__(self):
         return f'{self.title} (id={self.id})' or _("Business number %d") % self.pk
 
     class Meta:
         db_table = 'project'
-    
-    
+
+
 class ProjectOnboardingSteps(models.Model):
-    """
-    """
-    DATA_UPLOAD    = "DU"
-    CONF_SETTINGS  = "CF"
-    PUBLISH        = "PB"
+    """ """
+
+    DATA_UPLOAD = "DU"
+    CONF_SETTINGS = "CF"
+    PUBLISH = "PB"
     INVITE_EXPERTS = "IE"
-    
+
     STEPS_CHOICES = (
         (DATA_UPLOAD, "Import your data"),
         (CONF_SETTINGS, "Configure settings"),
         (PUBLISH, "Publish project"),
-        (INVITE_EXPERTS, "Invite collaborators")
+        (INVITE_EXPERTS, "Invite collaborators"),
     )
-    
+
     code = models.CharField(max_length=2, choices=STEPS_CHOICES, null=True)
-    
-    title       = models.CharField(_('title'), max_length=1000, null=False)
+
+    title = models.CharField(_('title'), max_length=1000, null=False)
     description = models.TextField(_('description'), null=False)
-    order       = models.IntegerField(default=0)
-    
+    order = models.IntegerField(default=0)
+
     created_at = models.DateTimeField(_('created at'), auto_now_add=True)
     updated_at = models.DateTimeField(_('updated at'), auto_now=True)
 
@@ -609,8 +700,8 @@ class ProjectOnboardingSteps(models.Model):
 
 
 class ProjectOnboarding(models.Model):
-    """
-    """
+    """ """
+
     step = models.ForeignKey(ProjectOnboardingSteps, on_delete=models.CASCADE, related_name="po_through")
     project = models.ForeignKey(Project, on_delete=models.CASCADE)
 
@@ -628,7 +719,9 @@ class ProjectOnboarding(models.Model):
 
 class ProjectMember(models.Model):
 
-    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='project_memberships', help_text='User ID')  # noqa
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='project_memberships', help_text='User ID'
+    )  # noqa
     project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='members', help_text='Project ID')
     enabled = models.BooleanField(default=True, help_text='Project member is enabled')
     created_at = models.DateTimeField(_('created at'), auto_now_add=True)
@@ -642,16 +735,21 @@ class ProjectSummary(models.Model):
 
     # { col1: task_count_with_col1, col2: task_count_with_col2 }
     all_data_columns = JSONField(
-        _('all data columns'), null=True, default=dict, help_text='All data columns found in imported tasks')
+        _('all data columns'), null=True, default=dict, help_text='All data columns found in imported tasks'
+    )
     # [col1, col2]
     common_data_columns = JSONField(
-        _('common data columns'), null=True, default=list, help_text='Common data columns found across imported tasks')
+        _('common data columns'), null=True, default=list, help_text='Common data columns found across imported tasks'
+    )
     # { (from_name, to_name, type): annotation_count }
     created_annotations = JSONField(
-        _('created annotations'), null=True, default=dict, help_text='Unique annotation types identified by tuple (from_name, to_name, type)')  # noqa
+        _('created annotations'),
+        null=True,
+        default=dict,
+        help_text='Unique annotation types identified by tuple (from_name, to_name, type)',
+    )  # noqa
     # { from_name: {label1: task_count_with_label1, label2: task_count_with_label2} }
-    created_labels = JSONField(
-        _('created labels'), null=True, default=dict, help_text='Unique labels')
+    created_labels = JSONField(_('created labels'), null=True, default=dict, help_text='Unique labels')
 
     def has_permission(self, user):
         return self.project.has_permission(user)
@@ -715,12 +813,13 @@ class ProjectSummary(models.Model):
 
     def _get_annotation_key(self, result):
         result_type = result.get('type', None)
-        if result_type in ('relation', 'rating', 'pairwise', None):
+        if result_type in ('relation', 'pairwise', None):
             return None
         if 'from_name' not in result or 'to_name' not in result:
             logger.error(
-                'Unexpected annotation.result format: "from_name" or "to_name" not found in %r', result,
-                extra={'sentry_skip': True}
+                'Unexpected annotation.result format: "from_name" or "to_name" not found in %r',
+                result,
+                extra={'sentry_skip': True},
             )
             return None
         result_from_name = result['from_name']
@@ -729,13 +828,19 @@ class ProjectSummary(models.Model):
 
     def _get_labels(self, result):
         result_type = result.get('type')
+        result_value = result['value'].get(result_type)
+        if not result_value or not isinstance(result_value, list) or result_type == 'text':
+            # Non-list values are not labels. TextArea list values (texts) are not labels too.
+            return []
+        # Labels are stored in list
         labels = []
-        for label in result['value'].get(result_type, []):
-            if isinstance(label, list):
-                labels.extend(label)
+        for label in result_value:
+            if result_type == 'taxonomy' and isinstance(label, list):
+                for label_ in label:
+                    labels.append(str(label_))
             else:
-                labels.append(label)
-        return [str(l) for l in labels]
+                labels.append(str(label))
+        return labels
 
     def update_created_annotations_and_labels(self, annotations):
         created_annotations = dict(self.created_annotations)
