@@ -5,7 +5,7 @@ import logging
 import os
 import datetime
 
-from urllib.parse import urljoin
+from urllib.parse import urljoin, quote
 
 from django.conf import settings
 from django.db import models, connection, transaction
@@ -48,7 +48,7 @@ class Task(TaskMixin, models.Model):
     updated_at = models.DateTimeField(_('updated at'), auto_now=True, help_text='Last time a task was updated')
     is_labeled = models.BooleanField(_('is_labeled'), default=False,
                                      help_text='True if the number of annotations for this task is greater than or equal '
-                                               'to the number of maximum_completions for the project')
+                                               'to the number of maximum_completions for the project', db_index=True)
     overlap = models.IntegerField(_('overlap'), default=1, db_index=True,
                                   help_text='Number of distinct annotators that processed the current task')
     file_upload = models.ForeignKey(
@@ -60,6 +60,16 @@ class Task(TaskMixin, models.Model):
     objects = TaskManager()  # task manager by default
     prepared = PreparedTaskManager()  # task manager with filters, ordering, etc for data_manager app
 
+    class Meta:
+        db_table = 'task'
+        ordering = ['-updated_at']
+        indexes = [
+            models.Index(fields=['project', 'is_labeled']),
+            models.Index(fields=['id', 'overlap']),
+            models.Index(fields=['overlap']),
+            models.Index(fields=['is_labeled'])
+        ]
+
     @property
     def file_upload_name(self):
         return os.path.basename(self.file_upload.file.name)
@@ -106,11 +116,7 @@ class Task(TaskMixin, models.Model):
     def get_lock_ttl(self):
         if settings.TASK_LOCK_TTL is not None:
             return settings.TASK_LOCK_TTL
-        avg_lead_time = self.project.annotations_lead_time()
-        ttl = settings.TASK_LOCK_DEFAULT_TTL
-        if avg_lead_time:
-            ttl = settings.TASK_LOCK_MIN_TTL + 3 * int(avg_lead_time)
-        return ttl
+        return settings.TASK_LOCK_MIN_TTL
 
     def has_permission(self, user):
         return self.project.has_permission(user)
@@ -122,9 +128,10 @@ class Task(TaskMixin, models.Model):
         """Lock current task by specified user. Lock lifetime is set by `expire_in_secs`"""
         num_locks = self.num_locks
         if num_locks < self.overlap:
-            expire_at = now() + datetime.timedelta(seconds=self.get_lock_ttl())
+            lock_ttl = self.get_lock_ttl()
+            expire_at = now() + datetime.timedelta(seconds=lock_ttl)
             TaskLock.objects.create(task=self, user=user, expire_at=expire_at)
-            logger.debug(f'User={user} acquires a lock for the task={self} ttl: {self.get_lock_ttl()}')
+            logger.debug(f'User={user} acquires a lock for the task={self} ttl: {lock_ttl}')
         else:
             logger.error(
                 f"Current number of locks for task {self.id} is {num_locks}, but overlap={self.overlap}: "
@@ -150,27 +157,37 @@ class Task(TaskMixin, models.Model):
             protected_data = {}
             for key, value in task_data.items():
                 if isinstance(value, str) and string_is_url(value):
-                    path = reverse('projects-file-proxy', kwargs={'pk': self.project.pk}) + '?url=' + value
+                    path = reverse('projects-file-proxy', kwargs={'pk': self.project.pk}) + '?url=' + quote(value)
                     value = urljoin(settings.HOSTNAME, path)
                 protected_data[key] = value
             return protected_data
         else:
             # Try resolve URLs via storage associated with that task
-            storage = self._get_task_storage(task_data)
-            if storage:
-                return storage.resolve_task_data_uri(task_data)
+            storage = self.storage
+            for field in task_data:
+                storage = storage or self._get_storage_by_url(task_data[field])
+                if storage:
+                    try:
+                        resolved_uri = storage.resolve_uri(task_data[field])
+                    except Exception as exc:
+                        logger.error(exc, exc_info=True)
+                        resolved_uri = None
+                    if resolved_uri:
+                        task_data[field] = resolved_uri
             return task_data
 
-    def _get_storage_by_task_data(self, task_data):
-        from io_storages.models import get_import_storage_by_url
+    def _get_storage_by_url(self, url):
+        """Find the first compatible storage and returns presigned URL"""
+        from io_storages.models import get_storage_classes
 
-        for url in task_data.values():
-            storage_class = get_import_storage_by_url(url)
-            if storage_class:
-                # Only first matched storage is returned - no way to specify {"url1": "s3://", "url2": "gs://"}
-                return storage_class.objects.filter(project=self.project).first()
+        for storage_class in get_storage_classes('import'):
+            storage_objects = storage_class.objects.filter(project=self.project)
+            for storage_object in storage_objects:
+                if storage_object.can_resolve_url(url):
+                    return storage_object
 
-    def _get_task_storage(self, task_data):
+    @property
+    def storage(self):
         # maybe task has storage link
         storage_link = self.get_storage_link()
         if storage_link:
@@ -183,10 +200,6 @@ class Task(TaskMixin, models.Model):
             from io_storages.s3.models import S3ImportStorage
             return S3ImportStorage()
 
-        storage = self._get_storage_by_task_data(task_data)
-        if storage:
-            return storage
-
     def update_is_labeled(self):
         """Set is_labeled field according to annotations*.count > overlap
         """
@@ -272,14 +285,6 @@ class Task(TaskMixin, models.Model):
     def ensure_unique_groundtruth(self, annotation_id):
         self.annotations.exclude(id=annotation_id).update(ground_truth=False)
 
-    class Meta:
-        db_table = 'task'
-        ordering = ['-updated_at']
-        indexes = [
-            models.Index(fields=['project', 'is_labeled']),
-            models.Index(fields=['id', 'overlap'])
-        ]
-
 
 pre_bulk_create = Signal(providing_args=["objs", "batch_size"])
 post_bulk_create = Signal(providing_args=["objs", "batch_size"])
@@ -328,11 +333,21 @@ class Annotation(AnnotationMixin, models.Model):
         null=True, default=dict, help_text='Prediction viewed at the time of annotation')
     result_count = models.IntegerField(_('result count'), default=0,
                                        help_text='Results inside of annotation counter')
-    
+
+    parent_prediction = models.ForeignKey('tasks.Prediction', on_delete=models.SET_NULL, related_name='child_annotations',
+                                          null=True, help_text='Points to the prediction from which this annotation was created')
+    parent_annotation = models.ForeignKey('tasks.Annotation', on_delete=models.SET_NULL,
+                                          related_name='child_annotations',
+                                          null=True,
+                                          help_text='Points to the parent annotation from which this annotation was created')
+
     class Meta:
         db_table = 'task_completion'
         indexes = [
-            models.Index(fields=['task', 'ground_truth'])
+            models.Index(fields=['task', 'ground_truth']),
+            models.Index(fields=['was_cancelled']),
+            models.Index(fields=['ground_truth']),
+            models.Index(fields=['created_at']),
         ]
 
     def created_ago(self):
