@@ -111,6 +111,15 @@ class TaskSimpleSerializer(ModelSerializer):
         self.fields['annotations'] = AnnotationSerializer(many=True, default=[], context=self.context, read_only=True)
         self.fields['predictions'] = PredictionSerializer(many=True, default=[], context=self.context, read_only=True)
 
+    def to_representation(self, instance):
+        project = instance.project
+        if project:
+            # resolve $undefined$ key in task data
+            data = instance.data
+            replace_task_data_undefined_with_config_field(data, project)
+
+        return super().to_representation(instance)
+
     class Meta:
         model = Task
         fields = '__all__'
@@ -126,7 +135,7 @@ class TaskSerializer(ModelSerializer):
                 many=True, read_only=False, required=False, context=self.context
             )
 
-    def project(self):
+    def project(self, task=None):
         """ Take the project from context
         """
         if 'project' in self.context:
@@ -134,6 +143,8 @@ class TaskSerializer(ModelSerializer):
         elif 'view' in self.context and 'project_id' in self.context['view'].kwargs:
             kwargs = self.context['view'].kwargs
             project = get_object_with_check_and_log(Project, kwargs['project_id'])
+        elif task:
+            project = task.project
         else:
             project = None
         return project
@@ -144,7 +155,7 @@ class TaskSerializer(ModelSerializer):
         return validator.validate(task)
 
     def to_representation(self, instance):
-        project = instance.project
+        project = self.project(instance)
         if project:
             # resolve uri for storage (s3/gcs/etc)
             if self.context.get('resolve_uri', False):
@@ -283,6 +294,10 @@ class TaskSerializerBulk(serializers.ListSerializer):
                          file_upload_id=task.get('file_upload_id'))
                 db_tasks.append(t)
 
+            # deprecated meta warning
+            if 'meta' in task:
+                logger.warning('You task data has field "meta" which is deprecated and it will be removed in future')
+
             if settings.DJANGO_DB == settings.DJANGO_DB_SQLITE:
                 self.db_tasks = []
                 try:
@@ -443,9 +458,9 @@ class AnnotationDraftSerializer(ModelSerializer):
             return ""
 
         name = user.first_name
-        if len(user.last_name):
-            name = name + " " + user.last_name
-
+        last_name = user.last_name
+        if len(last_name):
+            name = name + " " + last_name
         name += (' ' if name else '') + f'{user.email}, {user.id}'
         return name
 
