@@ -51,11 +51,11 @@ class TaskValidator:
 
             expected_types = _DATA_TYPES.get(data_type, (str, ))
             if not isinstance(data[data_key], tuple(expected_types)):
-                raise ValidationError('data["{data_key}"]={data_value} '
-                                      'is of type "{type}", '
-                                      'but types "{expected_types}" are expected'
+                raise ValidationError('data[\'{data_key}\']={data_value} is of type \'{type}\', '
+                                      "but the object tag {data_type} expects the following types: {expected_types}"
                                       .format(data_key=data_key, data_value=data[data_key],
-                                              type=type(data[data_key]), expected_types=expected_types))
+                                              type=type(data[data_key]).__name__, data_type=data_type,
+                                              expected_types=[e.__name__ for e in expected_types]))
 
             if data_type == 'List':
                 for item in data[data_key]:
