@@ -118,9 +118,7 @@ def test_next_task(
     r = any_client.get(f'/api/projects/{project.id}/next')
     assert r.status_code == status_code
     rdata = json.loads(r.content)
-    if r.status_code == 404:
-        assert rdata['detail'].startswith('There are no tasks remaining to be annotated')
-    else:
+    if r.status_code != 404:
         for response_key, expected_value_set in expected_response_value_set.items():
             if expected_value_set == 'uncompleted_task_ids':
                 expected_value_set = uncompleted_task_ids
@@ -460,8 +458,6 @@ def test_next_task_with_active_learning(mocker,
     rdata = json.loads(r.content)
     if r.status_code == 200:
         assert rdata['predictions'][0]['result'] == prelabeling_result
-    elif r.status_code == 404:
-        assert rdata['detail'].startswith('There are no tasks remaining to be annotated')
 
 
 @pytest.mark.django_db
