@@ -5,6 +5,7 @@ import drf_yasg.openapi as openapi
 
 from django_filters.rest_framework import DjangoFilterBackend
 from drf_yasg.utils import swagger_auto_schema
+from django.utils.decorators import method_decorator
 
 from rest_framework.views import APIView
 from rest_framework.response import Response
@@ -15,7 +16,7 @@ from rest_framework.decorators import action
 from rest_framework import generics
 from rest_framework.permissions import IsAuthenticated
 
-from core.permissions import CanModifyUserOrReadOnly
+from core.permissions import all_permissions
 from users.models import User
 from users.serializers import UserSerializer
 from users.functions import check_avatar
@@ -24,12 +25,49 @@ from users.functions import check_avatar
 logger = logging.getLogger(__name__)
 
 
+@method_decorator(name='update', decorator=swagger_auto_schema(
+    tags=['Users'],
+    operation_summary='Save user details',
+    operation_description="""
+    Save details for a specific user, such as their name or contact information, in Label Studio.
+    """,
+    request_body=UserSerializer
+))
+@method_decorator(name='list', decorator=swagger_auto_schema(
+        tags=['Users'],
+        operation_summary='List users',
+        operation_description='List the users that exist on the Label Studio server.'
+    ))
+@method_decorator(name='create', decorator=swagger_auto_schema(
+        tags=['Users'],
+        operation_summary='Create new user',
+        operation_description='Create a user in Label Studio.',
+        request_body=UserSerializer
+    ))
+@method_decorator(name='retrieve', decorator=swagger_auto_schema(
+        tags=['Users'],
+        operation_summary='Get user info',
+        operation_description='Get info about a specific Label Studio user, based on the user ID.'
+    ))
+@method_decorator(name='partial_update', decorator=swagger_auto_schema(
+        tags=['Users'],
+        operation_summary='Update user details',
+        operation_description="""
+        Update details for a specific user, such as their name or contact information, in Label Studio.
+        """,
+        request_body=UserSerializer
+    ))
+@method_decorator(name='destroy', decorator=swagger_auto_schema(
+        tags=['Users'],
+        operation_summary='Delete user',
+        operation_description='Delete a specific Label Studio user.',
+    ))
 class UserAPI(viewsets.ModelViewSet):
-    queryset = User.objects.all()
     serializer_class = UserSerializer
-    permission_classes = [CanModifyUserOrReadOnly]
-    filter_backends = [DjangoFilterBackend]
-    parser_classes = (JSONParser, MultiPartParser, FormParser)
+    permission_required = all_permissions.organizations_view
+
+    def get_queryset(self):
+        return User.objects.filter(organizations=self.request.user.active_organization)
 
     @swagger_auto_schema(auto_schema=None, methods=['delete', 'post'])
     @action(detail=True, methods=['delete', 'post'])
@@ -45,69 +83,29 @@ class UserAPI(viewsets.ModelViewSet):
             request.user.save()
             return Response(status=204)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='Save user details',
-        operation_description='Save details for a specific user, such as their name, contact information, '
-                              'or organization in Label Studio.',
-        request_body=UserSerializer
-    )
     def update(self, request, *args, **kwargs):
         return super(UserAPI, self).update(request, *args, **kwargs)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='List users',
-        operation_description='List the users that exist on the Label Studio server.'
-    )
     def list(self, request, *args, **kwargs):
         return super(UserAPI, self).list(request, *args, **kwargs)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='Create new user',
-        operation_description='Create a new user for Label Studio.',
-        request_body=UserSerializer
-    )
     def create(self, request, *args, **kwargs):
         return super(UserAPI, self).create(request, *args, **kwargs)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='Get user info',
-        operation_description='Get info about a specific Label Studio user.'
-    )
     def retrieve(self, request, *args, **kwargs):
         return super(UserAPI, self).retrieve(request, *args, **kwargs)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='Update user details',
-        operation_description='Update details for a specific user, such as their name, contact information, '
-                              'or organization in Label Studio.',
-        request_body=UserSerializer
-    )
     def partial_update(self, request, *args, **kwargs):
         return super(UserAPI, self).partial_update(request, *args, **kwargs)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='Delete user',
-        operation_description='Delete a specific Label Studio user.',
-    )
     def destroy(self, request, *args, **kwargs):
         return super(UserAPI, self).destroy(request, *args, **kwargs)
 
 
-class UserResetTokenAPI(APIView):
-    parser_classes = (JSONParser, FormParser, MultiPartParser)
-    queryset = User.objects.all()
-    permission_classes = (IsAuthenticated,)
-
-    @swagger_auto_schema(
+@method_decorator(name='post', decorator=swagger_auto_schema(
         tags=['Users'],
         operation_summary='Reset user token',
-        operation_description='Reset a specific user token.',
+        operation_description='Reset the user token for the current user.',
         responses={
             201: openapi.Response(
                 description='User token response',
@@ -121,7 +119,12 @@ class UserResetTokenAPI(APIView):
                         )
                     }
                 ))
-        })
+        }))
+class UserResetTokenAPI(APIView):
+    parser_classes = (JSONParser, FormParser, MultiPartParser)
+    queryset = User.objects.all()
+    permission_classes = (IsAuthenticated,)
+
     def post(self, request, *args, **kwargs):
         user = request.user
         token = user.reset_token()
@@ -129,25 +132,37 @@ class UserResetTokenAPI(APIView):
         return Response({'token': token.key}, status=201)
 
 
-class UserGetTokenAPI(APIView):
-    parser_classes = (JSONParser,)
-    permission_classes = (IsAuthenticated,)
-
-    @swagger_auto_schema(
+@method_decorator(name='get', decorator=swagger_auto_schema(
         tags=['Users'],
         operation_summary='Get user token',
-        operation_description='Get a user token to authenticate to the API as a specific user.',
+        operation_description='Get a user token to authenticate to the API as the current user.',
         responses={
             200: openapi.Response(
                 description='User token response',
-                schema=openapi.Schema(description='User token', type=openapi.TYPE_STRING))
-        })
+                type=openapi.TYPE_OBJECT,
+                properties={
+                    'detail': openapi.Schema(
+                        description='Token',
+                        type=openapi.TYPE_STRING
+                    )
+                }
+            )
+        }))
+class UserGetTokenAPI(APIView):
+    parser_classes = (JSONParser,)
+    permission_classes = (IsAuthenticated,)
+    
     def get(self, request, *args, **kwargs):
         user = request.user
         token = Token.objects.get(user=user)
-        return Response(str(token), status=200)
+        return Response({'token': str(token)}, status=200)
 
 
+@method_decorator(name='get', decorator=swagger_auto_schema(
+        tags=['Users'],
+        operation_summary='Retrieve my user',
+        operation_description='Retrieve details the account that you are using to access the API.'
+    ))
 class UserWhoAmIAPI(generics.RetrieveAPIView):
     parser_classes = (JSONParser, FormParser, MultiPartParser)
     queryset = User.objects.all()
@@ -157,10 +172,5 @@ class UserWhoAmIAPI(generics.RetrieveAPIView):
     def get_object(self):
         return User.objects.get(id=self.request.user.id)
 
-    @swagger_auto_schema(
-        tags=['Users'],
-        operation_summary='Retrieve my user',
-        operation_description='Retrieve details the account that you are using to access the API.'
-    )
     def get(self, request, *args, **kwargs):
         return super(UserWhoAmIAPI, self).get(request, *args, **kwargs)
